<?php
/**
 * Plugin Name: BPay for WooCommerce
 * Plugin URI: http://www.bpay.md
 * Description: BPay Payment gateway for WooCommerce
 * Version: 3.0.0
 * Author: CELLIXTEH SRL
 * Author URI: mailto:dev@bpay.md
 *
 * Requires Plugins: woocommerce
 */

if (!defined('ABSPATH')) {
    exit;
}

/**
 * Load plugin.
 */
add_action('plugins_loaded', 'bpay_plugin_init');
function bpay_plugin_init()
{
    if (!class_exists('WC_Payment_Gateway')) {
        return;
    }

    require_once plugin_dir_path(__FILE__) . 'includes/class-wc-gateway-bpay.php';
}

/**
 * Add BPay payment gateway to WooCommerce payment gateways.
 */
add_filter('woocommerce_payment_gateways', 'woocommerce_add_bpay_gateway');
function woocommerce_add_bpay_gateway($gateways)
{
    $gateways[] = 'BPay_Payment_Gateway';

    return $gateways;
}

/**
 * Declare the checkout blocks compatibility
 */
add_action('before_woocommerce_init', 'declare_cart_checkout_blocks_compatibility');
function declare_cart_checkout_blocks_compatibility()
{
    if (class_exists('\Automattic\WooCommerce\Utilities\FeaturesUtil')) {
        // WooCommerce Checkout Block Compatibility
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('cart_checkout_blocks', __FILE__, true);

        // WooCommerce HPOS compatibility
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__, true);

    }
}

/**
 * Load blocks
 */
add_action('woocommerce_blocks_loaded', 'bpay_gateway_block_support');
function bpay_gateway_block_support()
{
    if (!class_exists('Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType')) {
        return;
    }

    require_once plugin_dir_path(__FILE__) . 'includes/class-wc-gateway-bpay-block.php';

    add_action('woocommerce_blocks_payment_method_type_registration', function (Automattic\WooCommerce\Blocks\Payments\PaymentMethodRegistry $payment_method_registry) {
        $payment_method_registry->register(new BPay_Payment_Gateway_Block('bpay'));
    });
}
