<?php

use Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType;

class BPay_Payment_Gateway_Block extends AbstractPaymentMethodType
{
    /**
     * @var WC_Payment_Gateway
     */
    private $gateway;

    public function __construct($gatewayName = null)
    {
        if (!empty($gatewayName)) {
            $this->name = $gatewayName;
        }

        $this->initialize();
    }

    public function initialize()
    {
        $gateways = WC()->payment_gateways()->payment_gateways();
        $this->gateway = $gateways[$this->name];
    }

    public function is_active()
    {
        return !empty($this->gateway->enabled) && 'yes' === $this->gateway->enabled;
    }

    public function get_payment_method_data()
    {
        return [
            'title' => $this->gateway->title,
            'description' => $this->gateway->description,
            'icon' => $this->gateway->icon,
            'supports' => $this->gateway->supports
        ];
    }

    public function get_payment_method_script_handles()
    {
        wp_register_script(
            'bpay-gateway-blocks-integration',
            plugin_dir_url(__DIR__) . 'assets/js/block.js',
            [],
            null,
            true
        );

        if (function_exists('wp_set_script_translations')) {
            wp_set_script_translations('bpay-gateway-blocks-integration');
        }

        return ['bpay-gateway-blocks-integration'];
    }
}

